/*
 * Copyright 2022 Xilinx, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "common.h"

#if defined(NO_BUILTIN)
void* memset(void* s, int c, size_t n)
{
    uint8_t* pb = (uint8_t*)s;
    while(n > 0) {
        n--;
        *pb = (uint8_t)c;
        pb++;
    }
    return s;
}

void* memcpy(void *restrict dest,const void *restrict src, size_t n)
{
    uint8_t* pbDest = (uint8_t*)dest;
    uint8_t* pbSrc = (uint8_t*)src;
    while(n-- > 0) {
        *pbDest++ = *pbSrc++;
    }
    return dest;
}

int memcmp(const void* s1,const void* s2, size_t n)
{
    uint8_t* pbS1 = (uint8_t*)s1;
    uint8_t* pbS2 = (uint8_t*)s2;

    while(n-- > 0) {
        if(*pbS1 != *pbS2) {
            if(*pbS1 < *pbS2) {
                return -1;
            }
            return 1;
        }
        pbS1++;
        pbS2++;
    }
    return 0;
}
#else
void builtins_not_replaced(void) {}
#endif
